==> haskell-s-cargot-0.1.6.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-s-cargot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 s-cargot
version:              0.1.6.0
visibility:           public
id:                   s-cargot-0.1.6.0-C9vZt56Chu4KG6ZnL22VDK
key:                  s-cargot-0.1.6.0-C9vZt56Chu4KG6ZnL22VDK
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <s-cargot@infinitenegativeutility.com>
author:               Getty Ritter <s-cargot@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/s-cargot
synopsis:             A flexible, extensible s-expression library.
description:
    S-Cargot is a library for working with s-expressions in
    a modular and extensible way, opting for genericity and
    flexibility instead of speed. Instead of understanding
    one particular form of s-expression, the S-Cargot library
    exposes tools for parsing or emitting different kinds of
    s-expressions, including features not normally included
    in an s-expression library like reader macros or tight
    control over indentation in pretty-printing.

category:             Data
abi:                  863ee1c834dbc93e357ac7ea826b3ea8
exposed:              True
exposed-modules:
    Data.SCargot Data.SCargot.Atom Data.SCargot.Comments
    Data.SCargot.Common Data.SCargot.Language.Basic
    Data.SCargot.Language.HaskLike Data.SCargot.Parse
    Data.SCargot.Print Data.SCargot.Repr Data.SCargot.Repr.Basic
    Data.SCargot.Repr.Rich Data.SCargot.Repr.WellFormed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-s-cargot
hs-libraries:         HSs-cargot-0.1.6.0-C9vZt56Chu4KG6ZnL22VDK
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-s-cargot/html/s-cargot.haddock
haddock-html:         /usr/share/doc/haskell-s-cargot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-s-cargot-0.1.6.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-s-cargot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 s-cargot
version:              0.1.6.0
visibility:           public
id:                   s-cargot-0.1.6.0-AI482sxYrqv87x6JdB6gSZ
key:                  s-cargot-0.1.6.0-AI482sxYrqv87x6JdB6gSZ
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <s-cargot@infinitenegativeutility.com>
author:               Getty Ritter <s-cargot@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/s-cargot
synopsis:             A flexible, extensible s-expression library.
description:
    S-Cargot is a library for working with s-expressions in
    a modular and extensible way, opting for genericity and
    flexibility instead of speed. Instead of understanding
    one particular form of s-expression, the S-Cargot library
    exposes tools for parsing or emitting different kinds of
    s-expressions, including features not normally included
    in an s-expression library like reader macros or tight
    control over indentation in pretty-printing.

category:             Data
abi:                  3cb716b3fa98d901d6bba8c7edfee5e8
exposed:              True
exposed-modules:
    Data.SCargot Data.SCargot.Atom Data.SCargot.Comments
    Data.SCargot.Common Data.SCargot.Language.Basic
    Data.SCargot.Language.HaskLike Data.SCargot.Parse
    Data.SCargot.Print Data.SCargot.Repr Data.SCargot.Repr.Basic
    Data.SCargot.Repr.Rich Data.SCargot.Repr.WellFormed

import-dirs:          /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/s-cargot-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-s-cargot
hs-libraries:         HSs-cargot-0.1.6.0-AI482sxYrqv87x6JdB6gSZ
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-s-cargot/html/s-cargot.haddock
haddock-html:         /usr/share/doc/haskell-s-cargot/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
